@@ -1,7 +1,7 @@
 from django.contrib import admin
 
 # 引入用户平台
-from .models import PayMode, Currency, Transact, SandBox
+from .models import PayMode, Currency, Transact, SandBox, StatusCode
 
 
 # Register your models here.
@@ -22,24 +22,37 @@ class CurrencyAdmin(admin.ModelAdmin):
 
 
 class SandBoxAdmin(admin.ModelAdmin):
-    fields = ('id', 'sand_box_name',)
+    fields = ('id', 'sand_box_name', 'sand_box_label', 'description')
     list_display = ('id', 'sand_box_name', 'sand_box_label', 'description')
     search_fields = ('id', 'sand_box_name', 'sand_box_label', 'description')
     readonly_fields = ['id']
 
 
+class StatusCodeAdmin(admin.ModelAdmin):
+    fields = ('id', 'finance_status_code', 'description',)
+    list_display = ('id', 'finance_status_code', 'description',)
+    search_fields = ('id', 'finance_status_code', 'description',)
+    readonly_fields = ['id']
+
+
 class TransactAdmin(admin.ModelAdmin):
-    fields = ('id', 'account', 'their_account', 'transact_no', 'enroll_id', 'transact_time', 'platform_id', 'order_no',
+    fields = ('id', 'account', 'their_account', 'transact_no', 'thread_id', 'enroll_id', 'transact_time', 'platform_id',
+              'order_no',
               'opposite_account', 'summary', 'currency', 'income', 'outgo', 'balance', 'pay_mode', 'goods_info',
-              'pay_info', 'remark', 'images', 'sand_box', 'is_reverse',)
+              'pay_info', 'remark', 'images', 'sand_box', 'is_reverse', 'is_write_off', 'is_delete',
+              'sand_box_status_code', 'snapshot', 'finance_status_code')
     list_display = (
-        'id', 'account', 'their_account', 'transact_no', 'enroll_id', 'transact_time', 'platform_id', 'order_no',
+        'id', 'account', 'their_account', 'transact_no', 'thread_id', 'enroll_id', 'transact_time', 'platform_id',
+        'order_no',
         'opposite_account', 'summary', 'currency', 'income', 'outgo', 'balance', 'pay_mode', 'goods_info',
-        'pay_info', 'remark', 'images', 'sand_box', 'is_reverse',)
+        'pay_info', 'remark', 'images', 'sand_box', 'is_reverse', 'is_write_off', 'is_delete', 'sand_box_status_code',
+        'finance_status_code')
     search_fields = (
-        'id', 'account', 'their_account', 'transact_no', 'enroll_id', 'transact_time', 'platform_id', 'order_no',
+        'id', 'account', 'their_account', 'transact_no', 'thread_id', 'enroll_id', 'transact_time', 'platform_id',
+        'order_no',
         'opposite_account', 'summary', 'currency', 'income', 'outgo', 'balance', 'pay_mode', 'goods_info',
-        'pay_info', 'remark', 'images', 'sand_box', 'is_reverse',)
+        'pay_info', 'remark', 'images', 'sand_box', 'is_reverse', 'is_write_off', 'is_delete', 'sand_box_status_code',
+        'finance_status_code')
     # list_filter = ['platform', 'currency', 'account', 'their_account', 'order_no']
     readonly_fields = ['id', 'transact_time']
     # def platform(self, obj):
@@ -55,3 +68,4 @@ admin.site.register(Transact, TransactAdmin)
 admin.site.register(PayMode, PayModeAdmin)
 admin.site.register(Currency, CurrencyAdmin)
 admin.site.register(SandBox, SandBoxAdmin)
+admin.site.register(StatusCode, StatusCodeAdmin)
