@@ -182,47 +182,63 @@ class FinanceTransactService:
     @staticmethod
     def finance_flow_writing(params, fund_type=None):
 
-        # meet_data['sand_box'] = sand_box_receivable  # 沙盒应收
-        # meet_data['transact_no'] = FinanceService.make_unicode(str(applicant_person_id))  # 流水号
-        # meet_data['amount'] = amount
-        # meet_data['account_id'] = applicant_person_id  # 报名人id
-        # meet_data['their_account_id'] = finance_transact_data['their_account_id']
-        # meet_data['order_no'] = order_no  # 订单号
-        # meet_data['currency_id'] = finance_transact_data['currency_id']  # 币种
-        # meet_data['pay_mode_id'] = finance_transact_data['pay_mode_id']  # 支付方式
-        # meet_data['platform_id'] = finance_transact_data['platform_id']  # 所属平台
-        # meet_data['summary'] = finance_transact_data['summary']  # 摘要说明
-        # meet_data['finance_status_code'] = 2  # 资金状态码 finance_status_code 242 报名成功 待付款
-        platform_finance_data = {}
-        user_finance_data = {}
-        if fund_type == "RECHARGE":
-            platform_finance_data['account_id'] = sub_appid  # 收款方
-            platform_finance_data['their_account_name'] = params['user_id']  # 付款方
+        amount = params.get('amount', 0.0)  # 如果是负数是应付反之是应收
+        if not amount:
+            return None, "金额不能为空"
+        transact_no = params.get('transact_no', "")  # 订单号
+        user_finance_data = {
+            'their_account_id': params.get("user_id", ""),
+            'their_account_name': sub_appid,
+            'currency': "CNY",
+            'pay_mode': params.get("pay_mode", ""),
+        }
+
+        platform_finance_data = {
+            'account_name': sub_appid,
+            'their_account_id': params.get("user_id", ""),
+            'currency': "CNY",
+            'pay_mode': params.get("pay_mode", ""),
+
+        }
+        if fund_type == "RECHARGE":  # 充值行为
+            platform_finance_data['amount'] = float(amount)
+            platform_finance_data['transact_no'] = str(transact_no) + "-2",
+            platform_finance_data['finance_status_code'] = 5  # 资金状态码 finance_status_code 124 已下单支付 待接单
             finance_add_data, err_txt = FinanceTransactService.post(platform_finance_data)
+
             if err_txt:
                 return None, err_txt
-            user_finance_data['account_id'] = params['user_id']  #
-            user_finance_data['their_account_name'] = sub_appid  # 付款方
-            user_add_data, user_err_txt = FinanceTransactService.post(platform_finance_data)
-            if user_err_txt:
-                return None, user_err_txt
+            user_finance_data['amount'] = -abs(float(amount))
+            user_finance_data['transact_no'] = str(transact_no) + "-1",
+            user_finance_data['finance_status_code'] = 5  # 资金状态码 finance_status_code 124 已下单支付 待接单
+            # user_add_data, user_err_txt = FinanceTransactService.post(user_finance_data)
+            # if user_err_txt:
+            #     return None, user_err_txt
+
+            print(">>>>platform_finance_data", platform_finance_data)
+            print(">>>>user_finance_data", user_finance_data)
         elif fund_type == "PAY":
-            platform_finance_data['account_id'] = sub_appid  # 收款方
-            platform_finance_data['their_account_name'] = params['user_id']  # 付款方
             platform_finance_data['sand_box'] = sand_box_meet  # 沙盒应付
+            platform_finance_data['amount'] = -abs(float(amount))
+            platform_finance_data['order_no'] = FinanceService.make_unicode()
+            platform_finance_data['transact_no'] = FinanceService.make_unicode(
+                str(platform_finance_data['account_name']))
+            platform_finance_data['finance_status_code'] = 2  # 资金状态码 finance_status_code 242 报名成功 待付款
             finance_add_data, err_txt = FinanceTransactService.post(platform_finance_data)
             if err_txt:
                 return None, err_txt
-            user_finance_data['account_id'] = params['user_id']  #
-            user_finance_data['their_account_name'] = sub_appid  # 付款方
             user_finance_data['sand_box'] = sand_box_receivable  # 沙盒应收
-            user_add_data, user_err_txt = FinanceTransactService.post(platform_finance_data)
+            user_finance_data['amount'] = float(amount)
+            user_finance_data['order_no'] = FinanceService.make_unicode()
+            user_finance_data['transact_no'] = FinanceService.make_unicode(str(user_finance_data['account_id']))
+            user_finance_data['finance_status_code'] = 2  # 资金状态码 finance_status_code 242 报名成功 待付款
+            user_add_data, user_err_txt = FinanceTransactService.post(user_finance_data)
             if user_err_txt:
                 return None, user_err_txt
         elif fund_type == "WITHDRAW":
-            user_finance_data['account_id'] = params['user_id']  # 收款方
-            user_finance_data['their_account_name'] = sub_appid  # 付款方
             user_finance_data['sand_box'] = sand_box_cash_withdrawal  # 提现
+            user_finance_data['amount'] = -abs(float(amount))
+            user_finance_data['order_no'] = FinanceService.make_unicode()
             finance_add_data, err_txt = FinanceTransactService.post(user_finance_data)
             if err_txt:
                 return None, None
@@ -281,15 +297,20 @@ class FinanceTransactService:
         else:
             item['platform_id'] = param.get('platform_id', '')
         # 发起交易的账号ID，如果没有则默认自己
-        account_id = int(param.get('account_id', ''))
-        item['account'] = BaseInfo.objects.filter(id=account_id).first()
-        if not item['account']:
-            return None, '用户account_id不存在'
+        account_id = int(param.get('account_id', 0))
+        account_name = (param.get('account_name', ''))
+        if account_id:
+            item['account'] = BaseInfo.objects.filter(id=account_id).first()
+            if not item['account']:
+                return None, '用户account_id不存在'
+        elif not account_id and account_name:
+            item['account'] = BaseInfo.objects.filter(nickname=account_name).first()
+            if not item['account']:
+                return None, '用户account_id不存在'
         # 承受交易的账号，要从数据库判断是否存在
         their_account_id = param.get('their_account_id', '')
         if their_account_id:
             their_account_id = int(their_account_id)
-        if their_account_id:
             item['their_account'] = BaseInfo.objects.filter(id=their_account_id).first()
             if not item['their_account']:
                 return None, '用户their_account_id不存在'
@@ -435,7 +456,7 @@ class FinanceTransactService:
             item['balance'] = balance
 
         # 平台订单号是可以允许重复的，如果没有平台订单号则输入交易号
-        order_no = int(param.get('order_no', transact_no))  # 如果没有平台订单号则填交易号
+        order_no = (param.get('order_no', transact_no))  # 如果没有平台订单号则填交易号
         item['order_no'] = order_no
 
         # 对方科目
