@@ -148,13 +148,16 @@ class FinanceTransactsService:
     @staticmethod
     def get(params, user_id):
         # ========== 三、内容的类型准确性检查 ==========
-
         valid = FinanceService.check_filter_validity(params=params)
         # print(">>> check_filter_validity", valid)
         if valid['err'] > 0:
             # return Response({'err': valid['err'], 'msg': valid['msg'], })
             return None, valid['msg']
-        transacts = Transact.objects.filter(account_id=user_id).filter(**valid['query_dict'])
+        if params.get("is_all", None):
+            transacts = Transact.objects.filter(**valid['query_dict'])
+        else:
+            transacts = Transact.objects.filter(account_id=user_id).filter(**valid['query_dict'])
+
         transacts = transacts.order_by('-transact_time')
         # print(params['transact_time_start'])
         if params.get("transact_time_start", None) and params.get("transact_time_end", None):
@@ -360,6 +363,7 @@ class FinanceTransactsService:
             if type == "write_off":
                 # v['transact_no'] = transact_no.rstrip(transact_no[-1]) + str(int(transact_no[-1])) + "-2"
                 v['transact_no'] = FinanceService.make_unicode(str(transact_no))  # 流水号
+                # v['finance_status_code'] = ""
                 finance_transact, post_err = FinanceTransactService.post(v)
                 if post_err:
                     return None, post_err
@@ -469,12 +473,16 @@ class FinanceTransactsService:
     @staticmethod
     def invoicing_approval(params):
         finance_id = params.get("finance_id", None)
+        if not finance_id:
+            return None, "id不能为空"
         finance = Transact.objects.filter(id=finance_id)
         finance_data = finance.first()
         finance_data = model_to_dict(finance_data)
         snapshot = finance_data['snapshot']
-
-        enroll_list = FinanceTransactsService.get_json_primary_key(snapshot)
+        enroll_list = []
+        for i in snapshot['data']:
+            enroll_list.append(i['id'])
+        # enroll_list = FinanceTransactsService.get_json_primary_key(snapshot)
         if not sys.modules.get("xj_enroll.service.enroll_services.EnrollServices"):
             from xj_enroll.service.enroll_services import EnrollServices
         EnrollServices.enroll_edit(params={"finance_invoicing_code": "Invoiced"},
@@ -484,9 +492,9 @@ class FinanceTransactsService:
         # print(enroll_list)
         return None, None
 
-    @staticmethod
-    def get_json_primary_key(json):
-        enroll_list = []
-        for item in json:
-            enroll_list.append(item['id'])
-        return enroll_list
+    # @staticmethod
+    # def get_json_primary_key(json):
+    #     enroll_list = []
+    #     for item in json:
+    #         enroll_list.append(item['id'])
+    #     return enroll_list
