@@ -28,9 +28,10 @@ urlpatterns = [
     # re_path(r'^_export/?$', ExportExcel.as_view(), ),
     re_path(r'^statistic/?$', FinanceStatistic.as_view(), ),
     re_path(r'^balance/?$', FinanceBalance.as_view(), ),
-    re_path(r'^distribution/?$', FinanceTransact.distribution, ),
-    re_path(r'^write_off/?$', FinanceTransact.write_off, ),
-    re_path(r'^invoicing_approval/?$', FinanceTransact.invoicing_approval, ),
+    re_path(r'^distribution/?$', FinanceTransacts.distribution, ),
+    re_path(r'^write_off/?$', FinanceTransacts.write_off, ),
+    re_path(r'^invoicing_approval/?$', FinanceTransacts.invoicing_approval, ),
+    re_path(r'^flow_writing/?$', FinanceTransact.finance_flow_writing, ),
     re_path(r'^cash_withdrawal/?$', FinanceBalance.cash_withdrawal, ),
     re_path(r'^status_code/?$', FinanceStatusCode.as_view(), ),
 
